<?php

declare(strict_types=1);

namespace Drupal\config_warning\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Config Warning settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'config_warning_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['config_warning.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable warning message'),
      '#default_value' => $this->config('config_warning.settings')->get('enabled'),
      '#description' => $this->t("Should the warning message be shown to the admin user? It's convenient to have this disabled during development and then enable it on production."),
    ];
    $form['warning_message'] = [
      '#type' => 'textarea',
      '#rows' => 3,
      '#title' => $this->t('Warning message'),
      '#default_value' => $this->config('config_warning.settings')->get('warning_message'),
      '#description' => $this->t("Add the warning message you want to display. Maybe you have a policy you can refer people to?"),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('config_warning.settings')
      ->set('warning_message', $form_state->getValue('warning_message'))
      ->set('enabled', $form_state->getValue('enabled'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
